@@ -10,12 +10,11 @@ use Class::Std;
 use SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
 use LWP::UserAgent;
 
-our $VERSION='2.00_16';
+our $VERSION='2.00_17';
 
 my %no_dispatch_of      :ATTR(:name<no_dispatch>);
 my %wsdl_of             :ATTR(:name<wsdl>);
 my %proxy_of            :ATTR(:name<proxy>);
-my %readable_of         :ATTR(:name<readable>);
 my %autotype_of         :ATTR(:name<autotype>);
 my %outputxml_of        :ATTR(:name<outputxml> :default<0>);
 my %outputtree_of       :ATTR(:name<outputtree>);
@@ -31,7 +30,6 @@ my %binding_of          :ATTR(:default<()>);
 my %service_of          :ATTR(:default<()>);
 my %definitions_of      :ATTR(:get<definitions> :default<()>);
 my %serialize_options_of :ATTR(:default<()>);
-my %explain_options_of  :ATTR(:default<()>);
 
 my %client_of           :ATTR(:name<client>     :default<()>);
 my %keep_alive_of       :ATTR(:name<keep_alive> :default<0> );
@@ -41,7 +39,6 @@ my %LOOKUP = (
   class_resolver        => \%class_resolver_of,
   wsdl                  => \%wsdl_of,
   proxy                 => \%proxy_of,
-  readable              => \%readable_of,
   autotype              => \%autotype_of,
   outputxml             => \%outputxml_of,
   outputtree            => \%outputtree_of,
@@ -51,6 +48,15 @@ my %LOOKUP = (
   keep_alive            => \%keep_alive_of,
 );
 
+sub readable { warn <<EOT;
+'readable' has no effect any more. If you want formatted XML, 
+copy the debug output to your favorite XML editor and run the 
+source format command. 
+EOT
+}
+
+sub set_readable; *set_readable = \&readable;
+
 for my $method (keys %LOOKUP ) {
     no strict qw(refs);
     *{ $method } = sub {
@@ -107,8 +113,9 @@ sub wsdlinit {
     my $parser = SOAP::WSDL::Expat::WSDLParser->new();
     $parser->parse_string( $response->content() );
 
+    my $wsdl_definitions = $parser->get_data();
+
     # sanity checks
-    my $wsdl_definitions = $parser->get_data() or die "unable to parse WSDL";
     my $types = $wsdl_definitions->first_types()
         or die "unable to extract schema from WSDL";
     my $ns = $wsdl_definitions->get_xmlns()
@@ -122,12 +129,6 @@ sub wsdlinit {
         typelib   => $types,
         namespace => $ns,
     };
-    $explain_options_of{ $ident } = {
-        readable  => $self->readable(),
-        wsdl      => $wsdl_definitions,
-        namespace => $ns,
-        typelib   => $types,
-    };
 
     $servicename_of{ $ident } = $opt{servicename} if $opt{servicename};
     $portname_of{ $ident } = $opt{portname} if $opt{portname};
@@ -277,7 +278,7 @@ sub call {
     my $method_info = $method_info_of{ $ident }->{ $method };
 
     # TODO serialize both header and body, not only header
-    my $response = (blessed $data) 
+    my (@response) = (blessed $data) 
         ? $client->call( {
             operation => $method,
             soap_action => $method_info->{ soap_action },
@@ -289,7 +290,6 @@ sub call {
                 $content .= $part->serialize( $method, $data, 
                   {
                     %{ $serialize_options_of{ $ident } },
-                    readable => $readable_of{ $ident },
                   }  );
             }
             $client->call(
@@ -308,14 +308,8 @@ sub call {
             );
         };
 
-    return unless defined $response;    # nothing to do for one-ways
-    return $response;
-} 
-
-sub explain {
-    my $ident = ident shift;
-    my $opt  = $explain_options_of{ $ident };
-    return $definitions_of{ $ident }->explain( $opt );
+    return unless @response;    # nothing to do for one-ways
+    return wantarray ? @response : $response[0];
 } 
 
 1;
@@ -340,7 +334,6 @@ SOAP client, which mimics L<SOAP::Lite|SOAP::Lite>'s API, read on.
 
  my $soap = SOAP::WSDL->new(
     wsdl => 'file://bla.wsdl',
-    readable => 1,
  );
  
  my $result = $soap->call('MyMethod', %data);
@@ -384,6 +377,13 @@ Does not support SOAP header data.
 Does support SOAP header data. $body_ref and $header ref may either be 
 hash refs or SOAP::WSDL::XSD::Typelib::* derived objects.
 
+Result headers are accessible via the result SOAP::SOM object.
+
+If outputtree or outputhash are set, you may also use the following to 
+access response header data: 
+
+ my ($body, $header) = $soap->call('method', $body_ref, $header_ref );
+
 =back
 
 =head2 wsdlinit
@@ -412,7 +412,7 @@ When outputtree is set, SOAP::WSDL will return an object tree instead of a
 SOAP::SOM object.
 
 You have to specify a class_resolver for this to work. See 
-<class_resolver|class_resolver>
+L<class_resolver|class_resolver>
 
 =head2 class_resolver
 
@@ -422,8 +422,8 @@ Class resolvers must implement the method get_class which has to return the
 name of the class name for deserializing a XML node at the current XPath 
 location.
 
-Class resolvers are typically generated by using the to_typemap method on a 
-SOAP::WSDL::Definitions objects.
+Class resolvers are typically generated by using the generate_typemap method 
+of a SOAP::WSDL::Generator subclass.
 
 Example:
 
@@ -483,15 +483,6 @@ SOAP call to the SOAP service. Handy for testing/debugging.
 Returns the SOAP client implementation used (normally a SOAP::WSDL::Client 
 object).
 
-Useful for enabling tracing:
-
- # enable tracing via 'warn'
- $soap->get_client->set_trace(1);
- 
- # enable tracing via a custom facility - 
- # Log::Log4perl in this case...
- $soap->get_client->set_trace(sub { Log::Log4perl->get_logger->info(@_) } );
-
 =head1 EXAMPLES
 
 See the examples/ directory.
@@ -504,7 +495,7 @@ See the examples/ directory.
 
 SOAP::WSDL 2 is a complete rewrite. While SOAP::WSDL 1.x attempted to 
 process the WSDL file on the fly by using XPath queries, SOAP:WSDL 2 uses a 
-SAX filter for parsing the WSDL and building up a object tree representing 
+Expat handler for parsing the WSDL and building up a object tree representing 
 it's content.
 
 The object tree has two main functions: It knows how to serialize data passed 
@@ -515,12 +506,12 @@ L<SOAP::WSDL::Manual> for using it.
 
 =item * no_dispatch 
 
-call() with outputtxml set to true now returns the complete SOAP 
+call() with no_dispatch set to true now returns the complete SOAP request 
 envelope, not only the body's content.
 
 =item * outputxml
 
-call() with outputxml set to true now returns the complete SOAP 
+call() with outputxml set to true now returns the complete SOAP response
 envelope, not only the body's content.
 
 =item * servicename/portname
@@ -533,6 +524,14 @@ You may pass the servicename and portname as attributes to wsdlinit, though.
 
 =head1 Differences to SOAP::Lite
 
+=head2 readable
+
+readable is a no-op in SOAP::WSDL. Actually, the XML output from SOAP::Lite 
+is hardly readable, either with readable switched on.
+
+If you need readable XML messages, I suggest using your favorite XML editor 
+for displaying and formatting.
+
 =head2 Message style/encoding
 
 While SOAP::Lite supports rpc/encoded style/encoding only, SOAP::WSDL currently 
@@ -577,7 +576,7 @@ See below.
 SOAP::Lite returns only the content of the SOAP body when outputxml is set
 to true. SOAP::WSDL returns the complete XML response.
 
-=head3 Auto-Dispatching
+=head2 Auto-Dispatching
 
 SOAP::WSDL does B<does not> support auto-dispatching.
 
@@ -592,7 +591,7 @@ SOAP::WSDL::Client and implementing something like
 You may even do this in a class factory - see L<wsdl2perl.pl> for creating 
 such interfaces.
 
-=head3 Debugging / Tracing
+=head2 Debugging / Tracing
 
 While SOAP::Lite features a global tracing facility, SOAP::WSDL 
 allows to switch tracing on/of on a per-object base.
@@ -605,29 +604,30 @@ details.
 
 =over 
 
-=item * SOAP Headers are not supported
-
-There's no way to use SOAP Headers with SOAP::WSDL yet.
-
 =item * Apache SOAP datatypes are not supported
 
 You currently can't use SOAP::WSDL with Apache SOAP datatypes like map.
 
 If you want this changed, email me a copy of the specs, please.
 
-=item * outputhash
+=item * Incomplete XML Schema definitions support
 
-outputhash is not implemented yet.
+XML Schema attribute definitions are not supported yet.
 
-=item * Unsupported XML Schema definitions
+Importing external definitions is not supported yet.
 
-The following XML Schema definitions are not supported:
+The following XML Schema definitions varieties are not supported:
 
- choice
  group
  union
  simpleContent
- complexContent
+
+The following XML Schema definition content model is only partially 
+supported:
+
+ complexContent - only restriction variety supported
+
+See L<SOAP::WSDL::Manual::XSD> for details.
 
 =item * Serialization of hash refs dos not work for ambiguos values
 
@@ -731,9 +731,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 288 $
+ $Rev: 308 $
  $LastChangedBy: kutterma $
- $Id: WSDL.pm 288 2007-09-29 19:34:20Z kutterma $
+ $Id: WSDL.pm 308 2007-10-05 17:35:28Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL.pm $
  
 =cut
