@@ -11,7 +11,7 @@ use SOAP::WSDL::Factory::Serializer;
 use SOAP::WSDL::Factory::Transport;
 use SOAP::WSDL::Expat::MessageParser;
 
-our $VERSION = '2.00_16';
+our $VERSION = '2.00_17';
 
 my %class_resolver_of   :ATTR(:name<class_resolver> :default<()>);
 my %no_dispatch_of      :ATTR(:name<no_dispatch>    :default<()>);
@@ -21,7 +21,6 @@ my %endpoint_of         :ATTR(:name<endpoint>       :default<()>);
 
 my %soap_version_of     :ATTR(:get<soap_version>    :init_attr<soap_version> :default<'1.1'>);
 
-my %trace_of            :ATTR(:set<trace>           :init_arg<trace>    :default<()> );
 my %on_action_of        :ATTR(:name<on_action>      :default<()>);
 my %content_type_of     :ATTR(:name<content_type>   :default<text/xml; charset=utf8>);  #/#trick editors
 my %serializer_of       :ATTR(:name<serializer>     :default<()>);
@@ -37,15 +36,6 @@ sub BUILD {
        
 }
 
-sub get_trace {
-    my $ident = ident $_[0];
-    return $trace_of{ $ident } 
-      ? ref $trace_of{ $ident } eq 'CODE' 
-        ? $trace_of{ $ident }
-        : sub { warn @_ }
-    : ()
-}
-
 sub get_proxy {
     return $_[0]->get_transport();
 }
@@ -80,7 +70,6 @@ sub set_soap_version {
     # serializer object
     delete $serializer_of{ $ident };
     delete $deserializer_of{ $ident };
-    delete $transport_of{ $ident };
     
     $soap_version_of{ $ident } = shift;   
     
@@ -159,10 +148,7 @@ sub call {
        content_type => $content_type_of{ $ident },
        envelope => $envelope,
        action => $soap_action,
-       on_receive_chunk => sub {}     # optional, may be used for parsing large responses as they arrive.
-                                      # might not be supported by all transport layers...
-                                      # and, of course, only is of interest for chunk parsers - 
-                                      # namely ExpatNB and XML::LibXML's Push parser interface...
+       # on_receive_chunk => sub {}     # optional, may be used for parsing large responses as they arrive.
     );
 
     return $response if ($outputxml_of{ $ident } );
@@ -179,8 +165,14 @@ sub call {
     # Try deserializing response - there may be some,
     # even if transport did not succeed (got a 500 response)
     if ( $response ) {
-        my $result = eval { $deserializer_of{ $ident }->deserialize( $response ); };
-        return $result if (not $@);       
+        my ($result_body, $result_header) = eval { 
+            $deserializer_of{ $ident }->deserialize( $response ); 
+        };
+        if (not $@) {
+            return wantarray 
+                ? ($result_body, $result_header)
+                : $result_body;
+        }       
         return $deserializer_of{ $ident }->generate_fault({
             code => 'soap:Server',
             role => 'urn:localhost',
@@ -373,9 +365,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 288 $
+ $Rev: 303 $
  $LastChangedBy: kutterma $
- $Id: Client.pm 288 2007-09-29 19:34:20Z kutterma $
+ $Id: Client.pm 303 2007-10-01 18:51:50Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client.pm $
  
 =cut
