@@ -5,7 +5,7 @@ use Class::Std::Storable;
 use SOAP::WSDL::SOAP::Typelib::Fault11;
 use SOAP::WSDL::Expat::MessageParser;
 
-our $VERSION='2.00_13';
+our $VERSION='2.00_17';
 
 my %class_resolver_of :ATTR(:name<class_resolver> :default<()>);
 
@@ -19,7 +19,6 @@ sub BUILD {
 
 }
 
-
 sub deserialize {
     my ($self, $content) = @_;
         
@@ -35,7 +34,7 @@ sub deserialize {
                 . "Message was: \n$content"
         });
     }
-    return $parser->get_data();
+    return ( $parser->get_data(), $parser->get_header() );
 }
 
 sub generate_fault {
