@@ -3,14 +3,7 @@ use strict;
 use warnings;
 use Carp;
 use SOAP::WSDL::TypeLookup;
-use XML::Parser::Expat;
-
-sub new {
-    my ($class, $args) = @_;
-    my $self = {};
-    bless $self, $class;
-    return $self;
-}
+use base qw(SOAP::WSDL::Expat::Base);
 
 sub _initialize {
     my ($self, $parser) = @_;
@@ -146,33 +139,5 @@ sub _fixup_attrs {
     return @attrs_from;
 }
 
-sub parse {
-    $_[0]->_initialize( XML::Parser::Expat->new(
-        Namespaces => 1
-    ) )->parse( $_[1] );
-    $_[0]->{ parser }->release();    
-    return $_[0]->{ data };     
-}
-
-sub parsefile {
-    $_[0]->_initialize( XML::Parser::Expat->new(
-        Namespaces => 1
-    ) )->parsefile( $_[1] );
-    $_[0]->{ parser }->release();
-    return $_[0]->{ data };     
-}
-
-# aliases to make it more SAX-like
-sub parse_file;
-*parse_file = \&parsefile;
-
-sub parse_string;
-*parse_string = \&parse;
-
-
-sub get_data {
-    return $_[0]->{ data };
-}
-
 1;
 
