@@ -2,6 +2,8 @@ package SOAP::WSDL::Factory::Transport;
 use strict;
 use warnings;
 
+our $VERSION='2.00_17';
+
 # class data
 my %registered_transport_of = ();
 
@@ -34,8 +36,9 @@ sub get_transport {
 
     $scheme =~s{ \A ([^\:]+) \: .+ }{$1}smx;
        
-    if (exists $registered_transport_of{ $scheme }) {
-        eval "require $registered_transport_of{ $scheme }" or die $@;
+    if ($registered_transport_of{ $scheme }) {
+        eval "require $registered_transport_of{ $scheme }"
+            or die "Cannot load transport class $registered_transport_of{ $scheme } : $@";
         
         # try "foo::Client" class first - SOAP::Tranport always requires 
         # a package withoug the ::Client appended, and then
@@ -45,12 +48,12 @@ sub get_transport {
         # sparse resource ...
         # ... but we've decided to mimic SOAP::Lite...
 
-        my $protocol_class = $SOAP_LITE_TRANSPORT_OF{ $scheme } . '::Client';
-        my $transport;
-        eval {
-            $transport = $protocol_class->new( %attrs );
-        };
-        return $transport if not $@;
+#        my $protocol_class = $SOAP_LITE_TRANSPORT_OF{ $scheme } . '::Client';
+#        my $transport;
+#        eval {
+#            $transport = $protocol_class->new( %attrs );
+#        };
+#        return $transport if not $@;
         return $registered_transport_of{ $scheme }->new( %attrs );
     }
 
@@ -65,7 +68,8 @@ sub get_transport {
     }
 
     if (exists $SOAP_WSDL_TRANSPORT_OF{ $scheme }) {
-        eval "require $SOAP_WSDL_TRANSPORT_OF{ $scheme }" or die $@;
+        eval "require $SOAP_WSDL_TRANSPORT_OF{ $scheme }" 
+            or die "Cannot load transport class $SOAP_WSDL_TRANSPORT_OF{ $scheme } : $@";
         return $SOAP_WSDL_TRANSPORT_OF{ $scheme }->new( %attrs );
     }
 
@@ -232,9 +236,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 265 $
+ $Rev: 304 $
  $LastChangedBy: kutterma $
- $Id: Transport.pm 265 2007-09-20 21:51:31Z kutterma $
+ $Id: Transport.pm 304 2007-10-02 20:07:21Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Factory/Transport.pm $
  
 =cut
