@@ -3,6 +3,8 @@ use strict;
 use warnings;
 use Class::Std::Storable;
 
+our $VERSION = '2.00_17';
+
 my %definitions_of :ATTR(:name<definitions> :default<()>);
 my %type_prefix_of :ATTR(:name<type_prefix> :default<()>);
 my %element_prefix_of :ATTR(:name<element_prefix> :default<()>);
@@ -196,14 +198,10 @@ schema implementation.
 
 =head2 Implementation
 
-=head3 _accept 
+=head3 accept 
 
-SOAP::WSDL::Base defines an _accept method which expects a Visitor as only 
-parameter. The method is named _accept (and not the common "accept") to avoid 
-interferance with possible XML names (XML names must not start with a _).
-
-Don't let the _ prefix fool you: The method is B<not> private (though it is 
-meant to be called by Visitors only).
+SOAP::WSDL::Base defines an accept method which expects a Visitor as only 
+parameter.
 
 The method visit_Foo_Bar is called on the visitor, whith the self object as 
 parameter. 
@@ -232,7 +230,41 @@ to generate C# code from it...
 
 To write your own code generating visitor, you should subclass 
 SOAP::WSDL::Generator::Visitor. It implements (empty) default methods for all 
-SOAP::WSDL data classes.
+SOAP::WSDL data classes:
+
+=over
+
+=item * visit_Definitions
+
+=item * visit_Binding
+
+=item * visit_Message
+
+=item * visit_Operation
+
+=item * visit_OpMessage
+
+=item * visit_Part
+
+=item * visit_Port
+
+=item * visit_PortType
+
+=item * visit_Service
+
+=item * visit_SoapOperation
+
+=item * visit_Types
+
+=item * visit_XSD_Schema
+
+=item * visit_XSD_ComplexType
+
+=item * visit_XSD_Element
+
+=item * visit_XSD_SimpleType
+
+=back 
 
 In your Visitor, you must implement visit_Foo methods for all classes you wish 
 to visit.
