@@ -2,12 +2,10 @@ package SOAP::WSDL::Part;
 use strict;
 use warnings;
 use Carp qw(croak);
-use Class::Std::Fast::Storable;
+use Class::Std::Storable;
 
 use base qw(SOAP::WSDL::Base);
 
-use version; our $VERSION = qv('2.00.10');
-
 my %element_of  :ATTR(:name<element>    :default<()>);
 my %type_of     :ATTR(:name<type>       :default<()>);
 
@@ -18,17 +16,17 @@ sub serialize
     my $data = shift;
     my $opt = shift;
     my $typelib = $opt->{ typelib } || die "No typelib";
-    my %ns_map = %{ $opt->{ namespace } };
+    my %ns_map = reverse %{ $opt->{ namespace } };
 
     my $item_name;
     if ($item_name = $self->get_type() ) {
         # resolve type
         my ($prefix, $localname) = split /:/ , $item_name, 2;
-        my $type = $typelib->find_type( $ns_map{ $prefix }, $localname)
+        my $type = $typelib->find_type( $ns_map{ $prefix }, $localname	)
           or die "type $item_name , $ns_map{ $prefix } not found";
-
+          
         my $name = $self->get_name();
-        return $type->serialize( $name, $data->{ $name }, $opt );
+	   return $type->serialize( $name, $data->{ $name }, $opt );
     }
     elsif ( $item_name = $self->get_element() ) {
         my ($prefix, $localname) = split /:/ , $item_name, 2;
