@@ -1,4 +1,5 @@
 #!/usr/bin/perl -w
+# TODO rename to ::XSD
 package SOAP::WSDL::Serializer::SOAP11;
 use strict;
 use warnings;
@@ -31,18 +32,14 @@ sub serialize {
 
     while (my ($uri, $prefix) = each %{ $opt->{ namespace } })
     {
-        $xml .= "\n\t" if ($opt->{'readable'});
         $xml .= "xmlns:$prefix=\"$uri\" ";
     }
 
     # TODO insert encoding
     $xml.='>';
     $xml .= $self->serialize_header($args_of_ref->{ method }, $args_of_ref->{ header }, $opt);
-    $xml .= "\n" if ($opt->{ readable });
     $xml .= $self->serialize_body($args_of_ref->{ method }, $args_of_ref->{ body }, $opt);
-    $xml .= "\n" if ($opt->{ readable });
     $xml .= '</' . $soap_prefix .':Envelope>';
-    $xml .= "\n" if ($opt->{ readable });
     return $xml;
 }
 
@@ -51,7 +48,7 @@ sub serialize_header {
     
     # header is optional. Leave out if there's no header data
     return q{} if not $data;
-    return join ( ($opt->{ readable }) ? "\n" : q{}, 
+    return join ( q{}, 
         "<$opt->{ namespace }->{ $SOAP_NS }\:Header>",
         "$data",
         "</$opt->{ namespace }->{ $SOAP_NS }\:Header>",
@@ -63,7 +60,7 @@ sub serialize_body {
 
     # Body is NOT optional. Serialize to empty body 
     # if we have no data.
-    return join ( ($opt->{ readable }) ? "\n" : q{}, 
+    return join ( q{}, 
         "<$opt->{ namespace }->{ $SOAP_NS }\:Body>",
         defined $data ? "$data" : (),
         "</$opt->{ namespace }->{ $SOAP_NS }\:Body>",
