@@ -5,7 +5,8 @@ use Carp;
 use Class::Std::Storable;
 use Scalar::Util qw(blessed);
 use base qw/SOAP::WSDL::Base/;
-use Data::Dumper;
+
+our $VERSION='2.00_17';
 
 my %annotation_of   :ATTR(:name<annotation> :default<()>);
 my %element_of      :ATTR(:name<element>    :default<()>);
@@ -17,20 +18,10 @@ my %abstract_of     :ATTR(:name<abstract>   :default<()>);
 my %mixed_of        :ATTR(:name<mixed>      :default<()>);      # default is false
 
 # is set to simpleContent/complexContent
-my %content_Model_of    :ATTR(:name<contentModel>   :default<()>);
+my %content_model_of    :ATTR(:name<contentModel>   :default<()>);
 
 sub get_variety; *get_variety = \&get_flavor;
 
-sub find_element {
-    my ($self, @args) = @_;
-    my @found_at = grep {
-        $_->get_targetNamespace() eq $args[0] &&
-        $_->get_name() eq $args[1]
-    }
-    @{ $element_of{ ident $self } };
-    return $found_at[0];
-}
-
 sub push_element {
     my $self = shift;
     my $element = shift;
@@ -123,9 +114,5 @@ sub serialize {
     return $xml;
 }
 
-
-sub _check_value {
-	my $self = shift;
-}
 1;
 
