@@ -4,10 +4,11 @@ use warnings;
 use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
 
+our $VERSION='2.00_17';
+
 my %annotation_of   :ATTR(:name<annotation>     :default<()>);
 my %base_of         :ATTR(:name<base>           :default<()>);
 my %itemType_of     :ATTR(:name<itemType>       :default<()>);
-my %enumeration_of  :ATTR(:name<enumeration>    :default<()>);
 # is set to simpleContent/complexContent
 # my %content_model_of    :ATTR(:name<contentModel>   :default<()>);
 
@@ -54,17 +55,6 @@ sub set_union {
     }
 }
 
-sub push_enumeration {
-	my $self = shift;
-	my @attr = @_;
-	my @attributes = @_;
-	$self->set_flavor( 'enumeration' );
-	for (@attributes) {
-		next if (not $_->{ LocalName } eq 'value');
-		push @{ $enumeration_of{ ident $self } }, $_->{ 'Value' };
-	}
-}
-
 sub serialize {
     my $self = shift;
     my $name = shift;
@@ -74,9 +64,7 @@ sub serialize {
     
     $opt->{ attributes } ||= [];
     $opt->{ indent } ||= q{};
-    
-    $self->_check_value( $value );
-    
+      
     return $self->_serialize_single($name, $value , $opt)
       if ( $flavor_of{ $ident } eq 'restriction'
         or $flavor_of{ $ident } eq 'union'
@@ -110,8 +98,4 @@ sub _serialize_single {
     return $xml;
 }
 
-sub _check_value {
-	my $self = shift;
-}
-
 1;
